@@ -48,17 +48,13 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		//  basic_socket
 		/* ----------------------------------------------------------------- */
-		template <
-			int Family,
-			class CharT = char,
-			class Traits = std::char_traits<CharT>
-		>
+		template <int Family>
 		class basic_socket : public basic_rawsocket<SOCK_STREAM, Family> {
 		public:
 			typedef basic_rawsocket<SOCK_STREAM, Family> rawsocket;
 			typedef basic_sockaddress<Family, IPPROTO_TCP> sockaddress;
-			typedef CharT char_type;
-			typedef typename std::basic_string<CharT, Traits> string_type;
+			typedef char char_type;
+			typedef typename std::basic_string<char> string_type;
 			
 			// constructor and destructor
 			basic_socket() : rawsocket(), addr_() {}
@@ -108,15 +104,15 @@ namespace clx {
 				return this->connect(host.c_str(), service.c_str());
 			}
 			
-			int send(const char_type* dat, int n) {
+			virtual int send(const char_type* dat, int n) {
 				return ::send(this->socket(), dat, n, 0);
 			}
 			
-			int send(const string_type& dat) {
+			virtual int send(const string_type& dat) {
 				return this->send(dat.c_str(), static_cast<int>(dat.size()));
 			}
 			
-			int recv(char_type* buf, int n) {
+			virtual int recv(char_type* buf, int n) {
 				return ::recv(this->socket(), buf, n, 0);
 			}
 			
@@ -137,17 +133,13 @@ namespace clx {
 		/* ----------------------------------------------------------------- */
 		//  basic_acceptor
 		/* ----------------------------------------------------------------- */
-		template <
-			int Family,
-			class CharT = char,
-			class Traits = std::char_traits<CharT>
-		>
+		template <int Family>
 		class basic_acceptor : public basic_rawsocket<SOCK_STREAM, Family> {
 		public:
 			typedef basic_rawsocket<SOCK_STREAM, Family> rawsocket;
 			typedef basic_sockaddress<Family, IPPROTO_TCP> sockaddress;
-			typedef CharT char_type;
-			typedef typename std::basic_string<CharT, Traits> string_type;
+			typedef char char_type;
+			typedef typename std::basic_string<char> string_type;
 			
 			static const int default_nlisten = 100;
 			
