@@ -29,7 +29,7 @@
  *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  *  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  Last-modified: Tue 16 Jan 2007 04:56:00 JST
+ *  Last-modified: Tue 26 Aug 2008 07:49:00 JST
  */
 /* ------------------------------------------------------------------------- */
 #ifndef CLX_TOKENIZER_H
@@ -46,7 +46,7 @@ namespace clx {
 	/* --------------------------------------------------------------------- */
 	template <
 		class TokenizerFunc,
-		class Type = std::string,
+		class Type = std::basic_string<char>,
 		class Container = std::vector<Type>
 	>
 	class basic_tokenizer : public Container {
@@ -115,9 +115,14 @@ namespace clx {
 		functor f_;
 	};
 	
-	typedef basic_tokenizer<char_separator<char> > tokenizer;
-	typedef basic_tokenizer<escape_separator<char> > csv;
-	typedef basic_tokenizer<format_separator<char> > strftokenizer;
+	typedef basic_tokenizer<char_separator<char>, std::basic_string<char> > tokenizer;
+	typedef basic_tokenizer<escape_separator<char>, std::basic_string<char> > csv;
+	typedef basic_tokenizer<format_separator<char>, std::basic_string<char> > strftokenizer;
+#ifdef CLX_USE_WCHAR
+	typedef basic_tokenizer<char_separator<wchar_t>, std::basic_string<wchar_t> > wtokenizer;
+	typedef basic_tokenizer<escape_separator<wchar_t>, std::basic_string<wchar_t> > wcsv;
+	typedef basic_tokenizer<format_separator<wchar_t>, std::basic_string<wchar_t> > wstrftokenizer;
+#endif // CLX_USE_WCHAR
 	
 	/* --------------------------------------------------------------------- */
 	/*
